pub struct Note {
pub beat: f32,
pub row: i32,
pub col: i32,
pub color: NoteColor,
pub direction: CutDirection,
pub angle_offset: f32,
}Expand description
The standard block/note that a player cuts.
Fields
beat: f32The position of the object in time.
row: i32A value representing the vertical position of the object. In the range 0..2 inclusive, with zero being the bottom and two being the top row.
col: i32A value representing the horizontal position of the object. In the range 0..3 inclusive, with zero being the far left and three being the far right column.
color: NoteColorThe color that determines which saber should be used to cut the note.
direction: CutDirectionThe direction the note should be cut.
angle_offset: f32The number of degrees counter-clockwise to offset the object by.